Action

Struct Action 

pub struct Action { /* private fields */ }
Actions are records of events that have occurred on the resources in your account. These can be things like rebooting a Droplet, or transferring an image to a new region.

An action object is created every time one of these actions is initiated. The action object contains information about the current status of the action, start and complete timestamps, and the associated resource type and ID.

Every action that creates an action object is available through this endpoint. Completed actions are not removed from this list and are always available for querying.

Digital Ocean Documentation.

Implementations

Source

impl Action

pub fn id(&self) -> &usize

A unique identifier for each Droplet action event. This is used to reference a specific action that was requested.

pub fn status(&self) -> &String

The current status of the action. The value of this attribute will be “in-progress”, “completed”, or “errored”.

pub fn started_at(&self) -> &DateTime<Utc>

The type of action that the event is executing (reboot, power_off, etc.).

pub fn completed_at(&self) -> &Option<DateTime<Utc>>

A time value given in ISO8601 combined date and time format that represents when the action was completed.

pub fn resource_id(&self) -> &usize

A unique identifier for the resource that the action is associated with.

pub fn resource_type(&self) -> &String

The type of resource that the action is associated with.

pub fn region_slug(&self) -> &Option<String>

A slug representing the region where the action occurred.

Source

impl Action