Error

Enum Error 

pub enum Error {
    NotFound,
    Unauthorized,
    UnexpectedStatus(StatusCode),
    UnprocessableEntity(Value),
    ReqwestError(Error),
}
Errors which have crate specific meanings.

Variants



NotFound

The item does not exist or otherwise cannot be found.



Unauthorized

The reqest’s API key is invalid or not authorized to view this resource.



UnexpectedStatus(StatusCode)

An unexpected status code was returned from the API. Please raise a ticket.



UnprocessableEntity(Value)

The item exists (possibly on another account), the limit on this item has been reached, or this request is otherwise unprocessable.



ReqwestError(Error)

There was a miscellaneous error processing the request. Please look at the documentation of reqwest to learn more about how to handle these errors.